#! /bin/sh
# ====================================================
#               CS101 Shutdown Client
#                  Setup for Linux
#
#           Copyright (c) 2018 Legrand (r).
#                All Rights Reserved.
# ====================================================


# Program version
VERSION="1.1"


LANG_NAME_ENGLISH=English
LANG_ENGLISH=english
LANG_NAME_FRENCH=Français
LANG_FRENCH=french
LANG_NAME_HUNGARIAN=Magyar
LANG_HUNGARIAN=hungarian
LANG_NAME_ITALIAN=Italiano
LANG_ITALIAN=italian
ARCH_32=32
ARCH_64=64
YES=yes
NO=no
LICENCE_FILE=license.txt


# Global variables
PackageDir=""
Architecture=$ARCH_32
Language=$LANG_ENGLISH
LanguageName=$LANG_NAME_ENGLISH
Xmodules=$NO
Autostart=$YES

# Linux directories
LINUX_APP_MERGE_MENU_DIR=/etc/xdg/menus/applications-merged
LINUX_APP_AUTOSTART_DIR=/etc/xdg/autostart
LINUX_APP_MENU_DIR=/usr/share/desktop-directories
LINUX_APP_SHORTCUT_DIR=/usr/share/applications
LINUX_APP_ICON_DIR=/usr/share/pixmaps
LINUX_VAR_TMP_DIR=/var/tmp
LINUX_INIT_D_DIR=/etc/systemd/system
LINUX_INIT_SYSTEM_D="systemd"
LINUX_INIT_SYSTEM_V="SysVinit"
LINUX_INIT_SYSTEM_V_RC_START="2 3 4 5"
LINUX_INIT_SYSTEM_V_RC_STOP="0 1 6"

# Packages directories
PKG_NOARCH_DIR=noarch
PKG_32BIT_DIR=i386
PKG_64BIT_DIR=x86_64
PKG_LANGUAGES_DIR=languages
PKG_DOCUMENTS_DIR=documents
PKG_SCRIPTS_DIR=scripts
PKG_SHORTCUTS_DIR=shortcuts

# Installation directories
DST_LEGRAND_DIR=/usr/legrand
DST_PRODUCT_DIR=$DST_LEGRAND_DIR/cs101
DST_INSTALL_DIR=$DST_PRODUCT_DIR/client
DST_LANGUAGES_DIR=$DST_INSTALL_DIR/languages
DST_DOCUMENTS_DIR=$DST_INSTALL_DIR/documents

# Programs files
DAEMON_NAME=cs101client
CONFIG_NAME=config
XCONFIG_NAME=xconfig
CFG_FILE_NAME=config.cfg
XLOGVIEWER_NAME=xlogviewer
XMSGBOX_NAME=xmsgbox
INIT_V_START_SCRIPT_NAME=startcs101client
INIT_D_START_SCRIPT_NAME=cs101client.service
SHUTDOWN_SCRIPT_NAME=doshutdown.sh
MESSAGE_SCRIPT_NAME=message.sh
SET_VARIABLES_SCRIPT_NAME=setxvars.sh
INSTALL_SCRIPT_NAME=install.sh
LOCAL_DISPLAY_SETUP_SCRIPT_NAME=.local-display-setup.sh
XAUTOSTART_SHORTCUT_NAME=legrand-cs101client-setxvariables.desktop
XMENU_MERGE_NAME=Legrand.menu
XMENU_LEGRAND_DIR_NAME=Legrand.directory
XMENU_CS101_DIR_NAME=Legrand-cs101client.directory
XCONFIG_SHORTCUT_NAME=legrand-cs101client-xconfig.desktop
XLOGVIEWER_SHORTCUT_NAME=legrand-cs101client-xlogviewer.desktop
LEGRAND_ICON_NAME=legrand.png
XCONFIG_ICON_NAME=cs101-xconfig.png
XLOGVIEWER_ICON_NAME=cs101-xlogviewer.png

# Program files with destination folder
DAEMON=$DST_INSTALL_DIR/$DAEMON_NAME
CONFIG=$DST_INSTALL_DIR/$CONFIG_NAME
CFG_FILE=$DST_INSTALL_DIR/$CFG_FILE_NAME
XCONFIG=$DST_INSTALL_DIR/$XCONFIG_NAME
XLOGVIEWER=$DST_INSTALL_DIR/$XLOGVIEWER_NAME
XMSGBOX=$DST_INSTALL_DIR/$XMSGBOX_NAME
INIT_V_START_SCRIPT=$DST_INSTALL_DIR/$INIT_V_START_SCRIPT_NAME
INIT_D_START_SCRIPT=$LINUX_INIT_D_DIR/$INIT_D_START_SCRIPT_NAME
SHUTDOWN_SCRIPT=$DST_INSTALL_DIR/$SHUTDOWN_SCRIPT_NAME
MESSAGE_SCRIPT=$DST_INSTALL_DIR/$MESSAGE_SCRIPT_NAME
SET_VARIABLES_SCRIPT=$DST_INSTALL_DIR/$SET_VARIABLES_SCRIPT_NAME
INSTALL_SCRIPT=$DST_INSTALL_DIR/$INSTALL_SCRIPT_NAME
LOCAL_DISPLAY_SETUP_SCRIPT=$LINUX_VAR_TMP_DIR/$LOCAL_DISPLAY_SETUP_SCRIPT_NAME
XAUTOSTART_SHORTCUT=$LINUX_APP_AUTOSTART_DIR/$XAUTOSTART_SHORTCUT_NAME
XMENU_MERGE=$LINUX_APP_MERGE_MENU_DIR/$XMENU_MERGE_NAME
XMENU_LEGRAND_DIR=$LINUX_APP_MENU_DIR/$XMENU_LEGRAND_DIR_NAME
XMENU_CS101_DIR=$LINUX_APP_MENU_DIR/$XMENU_CS101_DIR_NAME
XCONFIG_SHORTCUT=$LINUX_APP_SHORTCUT_DIR/$XCONFIG_SHORTCUT_NAME
XLOGVIEWER_SHORTCUT=$LINUX_APP_SHORTCUT_DIR/$XLOGVIEWER_SHORTCUT_NAME
LEGRAND_ICON=$LINUX_APP_ICON_DIR/$LEGRAND_ICON_NAME
XCONFIG_ICON=$LINUX_APP_ICON_DIR/$XCONFIG_ICON_NAME
XLOGVIEWER_ICON=$LINUX_APP_ICON_DIR/$XLOGVIEWER_ICON_NAME




# ------------------------------------------
#  Check if the user is root
# ------------------------------------------
CheckUser()
{
	if [ $(id -u) -ne 0 ]; then 
		echo " "
		echo "ERROR: you must be root (or use sudo) to execute this program."
		echo " "
		exit 1
	fi
}


# ------------------------------------------
#  Detect the init system
#
# Return:
#   "sysvinit" or "systemv"
# ------------------------------------------
DetectInit()
{
	Sys=$(pidof systemd)
	if [ ${#Sys} -gt 0 ]; then
		echo $LINUX_INIT_SYSTEM_D
	else
		echo $LINUX_INIT_SYSTEM_V
	fi
}


# ------------------------------------------
#  Find "init" dir for "sysvinit" system
#
# Return:
#   Directory of "init.d"
# ------------------------------------------
FindInitDir()
{
	if [ -d /etc/init.d ]; then
		Dir=/etc/init.d
	elif [ -d /etc/rc.d/init.d ]; then
		Dir=/etc/rc.d/init.d
	elif [ -d /sbin/init.d ]; then
		Dir=/sbin/init.d
	elif [ -d /sbin/rc.d/init.d ]; then
		Dir=/sbin/rc.d/init.d
	else
		Dir=/etc/init.d
	fi

	echo $Dir
}


# -------------------------------------------
#  Remove RC links for "sysvinit" init system
# -------------------------------------------
RemoveRClinks()
{
	# start links
	for rl in $LINUX_INIT_SYSTEM_V_RC_START; do
		rl_mask="/etc/rc${rl}.d/*$INIT_V_START_SCRIPT_NAME"
		if [ -L $rl_mask ]; then
			unlink $rl_mask
		fi
	done

	# stop links
	for rl in $LINUX_INIT_SYSTEM_V_RC_STOP; do
		rl_mask="/etc/rc${rl}.d/*$INIT_V_START_SCRIPT_NAME"
		if [ -L $rl_mask ]; then
			unlink $rl_mask
		fi
	done
}


# ------------------------------------------
#  Create a directory and set permissions
#
# Parameters:
#   $1 : name of the directory
#   $2 : permissions
# ------------------------------------------
MakeDirectory()
{
	if [ ! -d "$1" ]; then
		mkdir $1
	fi
	chmod $2 $1	
}


# ------------------------------------------
#  Copy a file and set permissions
#
# Parameters:
#   $1 : original file (full path)
#   $2 : destination file (full path)
#   $3 : permissions
# ------------------------------------------
InstallFile()
{
	cp -f $1 $2
	chmod $3 $2
}


# ------------------------------------------
#  Copy multiple files and set permissions
#
# Parameters:
#   $1 : original file (full path)
#   $2 : destination file (full path)
#   $3 : permissions
# ------------------------------------------
InstallMultipleFiles()
{
	cp -f $1 $2
	for filename in $2/*; do
		chmod $3 $filename
	done
}


# ------------------------------------------
#  Get the pid of a process
#
# Parameters:
#   $1 process name
# Return:
#   pid
# ------------------------------------------
GetPid()
{
	pid=$(ps -ef | grep "\<$1\>" | grep -v grep | awk '{print $2}')
	echo $pid
} 


# ------------------------------------------
#  Write the main title
# ------------------------------------------
WriteMainTitle()
{
	clear
	#echo " "
	echo "===================================================="
	echo "              CS101 Shutdown Client"
	echo "                 Version $VERSION"
	echo "                 Setup for Linux"
	echo "===================================================="
	echo " "
}


# ------------------------------------------
#  Abort the installation and exit setup
#
# Parameters:
#   $1 = explanation text
# ------------------------------------------
AbortSetup()
{
	echo " "
	if [ -n "$1" ]; then
		echo $1
	fi
	echo "Installation aborted !"
	echo " "
	echo " "
	exit 1
}


# ------------------------------------------
#  Ask for "yes" or "no"
#
# Parameters:
#   $1 = Text to display
#   $2 = Suffix at the end of the text
# Return:
#   1 = yes
#   0 = no
# ------------------------------------------
AskYesNo()
{
	if [ -n "$2" ]; then
		Suffix=$2
	else
		Suffix=":"
	fi
	echo -n "$1 [y/n]$Suffix "
	read Choice
	case $Choice in
		y|Y)
			return 1
			;;
		n|N)
			return 0
			;;
		*)
			AskYesNo "$1" "$2"
	esac
}


# ------------------------------------------
#  Select architecture: 32 or 64 bit
# ------------------------------------------
AskForArchitecture()
{
	echo " "
	echo "   1) 32 bit"
	echo "   2) 64 bit"
	echo " "
	echo -n "Select architecture: "

	echo -n "Select architecture: "
	read Choice
	case $Choice in
		1)
			Architecture=$ARCH_32
			;;
		2)
			Architecture=$ARCH_64
			;;
		*)
			AskForArchitecture
			;;
	esac
}


# ------------------------------------------
#  Select language of the program
# ------------------------------------------
AskForLanguage()
{
	echo " "
	echo "   1) ${LANG_NAME_ENGLISH}"
	echo "   2) ${LANG_NAME_FRENCH}"
	echo "   3) ${LANG_NAME_HUNGARIAN}"
	echo "   4) ${LANG_NAME_ITALIAN}"
	echo " "
#	echo -n ">>> Select language: "
	echo -n "Select language: "
	read Choice
	case $Choice in
		1)
			Language=$LANG_ENGLISH
			LanguageName=$LANG_NAME_ENGLISH
			;;
		2)
			Language=$LANG_FRENCH
			LanguageName=$LANG_NAME_FRENCH
			;;
		3)
			Language=$LANG_HUNGARIAN
			LanguageName=$LANG_NAME_HUNGARIAN
			;;
		4)
			Language=$LANG_ITALIAN
			LanguageName=$LANG_NAME_ITALIAN
			;;
		*)
			AskForLanguage
			;;
	esac
}


# ------------------------------------------
#  Ask if install X modules
# ------------------------------------------
AskForXmodules()
{
	echo " "
#	AskYesNo "Do you want to install X modules" "?"
	AskYesNo "Do you want to use X messages" "?"
	RetVal="$?"
	if [ "$RetVal" = "1" ]; then
		Xmodules=$YES
	else
		Xmodules=$NO
	fi
}


# ------------------------------------------
#  Type of start: "auto" or "manual"
# ------------------------------------------
AskForStartType()
{
	echo " "
	AskYesNo "Do you want to start the program at system boot" "?"
	RetVal="$?"
	if [ "$RetVal" = "1" ]; then
		Autostart=$YES
	else
		Autostart=$NO
	fi
}


# ------------------------------------------
#  Stop a process
#
# Parameters:
#   $1 program name
#   $2 program directory and name
#   $3 parameter used to stop the process
# Return:
#   0 process has been stopped
#   1 process was already stopped
#   2 process could not be stopped
# ------------------------------------------
StopProcess()
{
	PROCESS_STOP_TRIES=10
	
	pid=$(GetPid $1)
	if [ -z "$pid" ]; then
		return 1
	fi

	if [ -n "$3" ]; then
		$2 "$3"
	else
		kill -TERM $pid
	fi

	while [ $PROCESS_STOP_TRIES -gt 0 ]
	do
		pid=$(GetPid $1)
		if [ -z "$pid" ]; then
			break
		fi
		PROCESS_STOP_TRIES=$((PROCESS_STOP_TRIES - 1))
		sleep 1
	done

	pid=$(GetPid $1)
	if [ -n "$pid" ]; then
		AbortSetup "Impossible to stop $CONFIG_NAME."
	fi
}


# ------------------------------------------
#  Install the mandatory files
# ------------------------------------------
InstallCoreFiles()
{
	echo " "
	echo -n "Installing core files... "
	
	# Create the directories and set the permissions
	MakeDirectory $DST_LEGRAND_DIR "755"
	MakeDirectory $DST_PRODUCT_DIR "755"
	MakeDirectory $DST_INSTALL_DIR "755"
	MakeDirectory $DST_LANGUAGES_DIR "755"
	MakeDirectory $DST_DOCUMENTS_DIR "755"

	# Copy the core files
	InstallFile "${PackageDir}/${INSTALL_SCRIPT_NAME}" "$INSTALL_SCRIPT" "755"
	InstallFile "${BinariesDir}/${DAEMON_NAME}" "$DAEMON" "755"
	InstallFile "${BinariesDir}/${CONFIG_NAME}" "$CONFIG" "755"
	InstallFile "${NoArchDir}/${PKG_SCRIPTS_DIR}/${INIT_V_START_SCRIPT_NAME}" "$INIT_V_START_SCRIPT" "755"
	InstallFile "${NoArchDir}/${PKG_SCRIPTS_DIR}/${SHUTDOWN_SCRIPT_NAME}" "$SHUTDOWN_SCRIPT" "755"
	InstallFile "${NoArchDir}/${PKG_SCRIPTS_DIR}/${MESSAGE_SCRIPT_NAME}" "$MESSAGE_SCRIPT" "755"
	InstallFile "${NoArchDir}/${CFG_FILE_NAME}" "$CFG_FILE" "664"
	InstallMultipleFiles "${NoArchDir}/${PKG_LANGUAGES_DIR}/*.lng" "$DST_LANGUAGES_DIR" "444"
	InstallMultipleFiles "${NoArchDir}/${PKG_DOCUMENTS_DIR}/${Language}/*" "$DST_DOCUMENTS_DIR" "444"

	# set the language in configuration file
	if [ "$Language" != "$LANG_ENGLISH" ]; then
		sed -i "s/$LANG_ENGLISH/$Language/" "$CFG_FILE"
	fi

	echo "done."
}


# ------------------------------------------
#  Install the X files
# ------------------------------------------
InstallXmodules()
{
	#	echo " "
#	echo -n "Installing X modules... "
	echo -n "Installing X message... "
	
	Error=0

	# Executable files
	InstallFile "${BinariesDir}/${XMSGBOX_NAME}" "$XMSGBOX" "755"
	InstallFile "${BinariesDir}/${XCONFIG_NAME}" "$XCONFIG" "755"
	InstallFile "${BinariesDir}/${XLOGVIEWER_NAME}" "$XLOGVIEWER" "755"
	
	# display and xauthority files and permissions
	MakeDirectory $LINUX_VAR_TMP_DIR "777"
	MakeDirectory $LINUX_APP_AUTOSTART_DIR "755"
	InstallFile "${NoArchDir}/${PKG_SHORTCUTS_DIR}/${XAUTOSTART_SHORTCUT_NAME}" "$XAUTOSTART_SHORTCUT" "644"
	InstallFile "${NoArchDir}/${PKG_SCRIPTS_DIR}/${SET_VARIABLES_SCRIPT_NAME}" "$SET_VARIABLES_SCRIPT" "777"
#	$SET_VARIABLES_SCRIPT
	
	# Menu shortcuts and icons
#	if [ -d "$LINUX_APP_SHORTCUT_DIR" ] && [ -d "$LINUX_APP_ICON_DIR" ]; then
#		InstallFile "${NoArchDir}/${PKG_SHORTCUTS_DIR}/${XCONFIG_SHORTCUT_NAME}" "$XCONFIG_SHORTCUT" "644"
#		InstallFile "${NoArchDir}/${PKG_SHORTCUTS_DIR}/${XLOGVIEWER_SHORTCUT_NAME}" "$XLOGVIEWER_SHORTCUT" "644"
#		InstallFile "${NoArchDir}/${PKG_SHORTCUTS_DIR}/${XCONFIG_ICON_NAME}" "$XCONFIG_ICON" "644"
#		InstallFile "${NoArchDir}/${PKG_SHORTCUTS_DIR}/${XLOGVIEWER_ICON_NAME}" "$XLOGVIEWER_ICON" "644"
#		InstallFile "${NoArchDir}/${PKG_SHORTCUTS_DIR}/${LEGRAND_ICON_NAME}" "$LEGRAND_ICON" "644"
#	else
#		Error=1
#	fi

	# Menu extension
#	if [ -d "$LINUX_APP_MENU_DIR" ]; then
#		InstallFile "${NoArchDir}/${PKG_SHORTCUTS_DIR}/${XMENU_LEGRAND_DIR_NAME}" "$XMENU_LEGRAND_DIR" "644"
#		InstallFile "${NoArchDir}/${PKG_SHORTCUTS_DIR}/${XMENU_CS101_DIR_NAME}" "$XMENU_CS101_DIR" "644"
#	fi

	# Menu merged file
#	if [ -d "$LINUX_APP_MERGE_MENU_DIR" ]; then
#		InstallFile "${NoArchDir}/${PKG_SHORTCUTS_DIR}/${XMENU_MERGE_NAME}" "$XMENU_MERGE" "644"
#	fi

	# Finish message
#	if [ $Error = 0 ]; then	
		echo "done."
#	else
#		echo "done but it was not possible to install the shortcuts on the desktop."
#		echo "You have to create them manually: the files involved are $XCONFIG_NAME and $XLOGVIEWER_NAME."
#	fi
}


# ------------------------------------------
#  Install the files for the automatic boot
# ------------------------------------------
InstallAutostartFiles()
{
#	echo " "
	echo -n "Detecting init system... "
	Init=$(DetectInit)
	echo "found \"$Init\"."

	if [ "$Init" = "$LINUX_INIT_SYSTEM_V" ]; then
		# remove any link related to the daemon		
		RemoveRClinks

		InitDir=$(FindInitDir)
		ScriptName="${InitDir}/${INIT_V_START_SCRIPT_NAME}"

		echo -n "Installing init script... "
		InstallFile "${NoArchDir}/${PKG_SCRIPTS_DIR}/${INIT_V_START_SCRIPT_NAME}" "$ScriptName" "755"
		echo "done."

		# RC links for start -> S99
		echo -n "Creating rc start links in runlevels $LINUX_INIT_SYSTEM_V_RC_START... "
		for rl in $LINUX_INIT_SYSTEM_V_RC_START; do
			rl_script="/etc/rc${rl}.d/S99$INIT_V_START_SCRIPT_NAME"
			ln -s $ScriptName $rl_script
		done
		echo "done."

		# RC links for stop -> K01
		echo -n "Creating rc stop links in runlevels $LINUX_INIT_SYSTEM_V_RC_STOP... "
		for rl in $LINUX_INIT_SYSTEM_V_RC_STOP; do
			rl_script="/etc/rc${rl}.d/K01$INIT_V_START_SCRIPT_NAME"
			ln -s $ScriptName $rl_script
		done
		echo "done."
	else
		echo -n "Installing service script... "
		InstallFile "${NoArchDir}/${PKG_SCRIPTS_DIR}/${INIT_D_START_SCRIPT_NAME}" "$INIT_D_START_SCRIPT" "644"
		systemctl -q enable $INIT_D_START_SCRIPT_NAME
		echo "done."
	fi
}


# ------------------------------------------
#  Install the product
# ------------------------------------------
InstallProduct()
{
	# Directory of common parts (architecture independent)
	NoArchDir="${PackageDir}/${PKG_NOARCH_DIR}"

	# Licence acceptance
	LicenceFile="${NoArchDir}/${PKG_DOCUMENTS_DIR}/${Language}/${LICENCE_FILE}"
	more $LicenceFile
	echo " "
	AskYesNo "Do you accept licence" "?"
	RetVal="$?"
	if [ "$RetVal" != "1" ]; then
		AbortSetup "Licence not accepted. You are not allowed to use this program."
	fi

	# Directory of binaries files based on architecture selected
	if [ $Architecture = $ARCH_64 ]; then
		BinariesDir="${PackageDir}/$PKG_64BIT_DIR"
	else
		BinariesDir="${PackageDir}/$PKG_32BIT_DIR"
	fi

	# Install common files	
	InstallCoreFiles

	# If required, install X files and configure the "message.sh" file
	if [ "$Xmodules" = "$YES" ]; then
		InstallXmodules
		# enables X messages
		sed -i "s/USE_GUI_MESSAGE=FALSE/USE_GUI_MESSAGE=TRUE/" "$MESSAGE_SCRIPT"
	else
		# disables X messages
		sed -i "s/USE_GUI_MESSAGE=TRUE/USE_GUI_MESSAGE=FALSE/" "$MESSAGE_SCRIPT"
	fi

	# If required, install necessary files for automatic boot
	if [ "$Autostart" = "$YES" ]; then
		InstallAutostartFiles
	fi

	echo " "
	AskYesNo "Do you want to run configuration program now" "?"
	RetVal="$?"
	if [ "$RetVal" = "1" ]; then
		$CONFIG
	else
		echo " "
#		if [ "$Xmodules" = "$YES" ]; then
#			echo "Run the configuration program in \"Legrand -> CS101\" or \"Internet\Network\" menu to configure the program."
#			echo "If shortcuts are not present in the menu, restart your X server."
#		else
			echo "IMPORTANT!!! Run \"$CONFIG\", otherwise the program won't works."
#		fi
	fi

	# Installation is finished
	echo " "
	echo "Installation finished. Program installed in \"$DST_INSTALL_DIR\"."
	
	if [ "$Xmodules" = "$YES" ]; then
		echo " "
		echo "To activate the graphical messages, restart the X server (logout and login again)."
		echo " "
	fi
	
	echo " "
	echo " "

	exit 0
}


# ------------------------------------------
#  Uninstall the product
# ------------------------------------------
UninstallProduct()
{
	echo " "
	AskYesNo "A previous installation was found. Uninstall it" "?"
	RetVal="$?"
	if [ "$RetVal" = "0" ]; then
		AbortSetup
	fi

	# stop the modules
	echo -n "Stopping programs... "
	StopProcess $DAEMON_NAME $DAEMON
	StopProcess $CONFIG_NAME $CONFIG
	StopProcess $XCONFIG_NAME $XCONFIG
	StopProcess $XLOGVIEWER_NAME $XLOGVIEWER
	StopProcess $XMSGBOX_NAME $XMSGBOX
	echo "done."

	# delete autostart files and scripts
	echo -n "Removing autostart links and files... "
	Init=$(DetectInit)
	if [ "$Init" = "$LINUX_INIT_SYSTEM_V" ]; then
		RemoveRClinks
		InitDir=$(FindInitDir)
		ScriptName="${InitDir}/${INIT_V_START_SCRIPT_NAME}"
		rm -f $ScriptName
	else
		systemctl -q disable $INIT_D_START_SCRIPT_NAME
		rm -f $INIT_D_START_SCRIPT
	fi
	echo "done."


	# delete files and directories	
	echo -n "Removing program files and directories... "
	# program directory and all the files
	rm -rf $DST_INSTALL_DIR
	# "product directory", if empty
	if [ -z "$(ls -A $DST_PRODUCT_DIR)" ]; then
		rm -rf $DST_PRODUCT_DIR
	fi
	# "manufacturer directory", if empty
	if [ -z "$(ls -A $DST_LEGRAND_DIR)" ]; then
		rm -rf $DST_LEGRAND_DIR
	fi
	echo "done."

	# delete shortcuts and icons
#	echo -n "Removing shortcuts and icons... "
	rm -f $LOCAL_DISPLAY_SETUP_SCRIPT
	rm -f $XAUTOSTART_SHORTCUT
	rm -f $XMENU_MERGE
	rm -f $XMENU_LEGRAND_DIR
	rm -f $XMENU_CS101_DIR
	rm -f $XCONFIG_SHORTCUT
	rm -f $XLOGVIEWER_SHORTCUT
	rm -f $XCONFIG_ICON
	rm -f $XLOGVIEWER_ICON
	rm -f $LEGRAND_ICON
#	echo "done."

	echo " "
	echo -n "Program uninstalled. Press ENTER to continue."
	read Choice
	echo " "
	echo " "
}


# ------------------------------------------
#  Main menu for Linux installation
# ------------------------------------------
LinuxSetupMenu()
{
	WriteMainTitle

	echo "   1) Architecture         : $Architecture bits"
	echo "   2) Language             : $LanguageName"
#	echo "   3) Install X modules    : $Xmodules"
	echo "   3) Use X messages       : $Xmodules"
	echo "   4) Start at system boot : $Autostart"
	echo " "
	echo "   8) Start installation"
	echo "   0) Cancel and exit"
	echo " "
	echo -n ">>> Select an option: "

	read Choice

	case $Choice in
		1)
			AskForArchitecture
			LinuxSetupMenu
			;;
		2)
			AskForLanguage
			LinuxSetupMenu
			;;
		3)
			AskForXmodules
			LinuxSetupMenu
			;;
		4)
			AskForStartType
			LinuxSetupMenu
			;;
		8)
			InstallProduct
			;;
		0)
			AbortSetup
			;;
		*)
			LinuxSetupMenu
			;;
	esac
}




# ================================================
#                      MAIN
# ================================================

WriteMainTitle

# Check if user is root
CheckUser

# read the full path of this script
if [ -L $0 ]; then
	ScrDir=$(readlink $0)
else
	ScrDir=$0
fi
PackageDir=$(dirname $ScrDir)
if [ -z "$PackageDir" ]; then
	AbortSetup "Error reading directory of the installation package."
	exit 1
fi

# Uninstall the program if already installed
if [ -x "$DAEMON" ]; then
	UninstallProduct
	exit 0
fi

# try to read the architecture
if [ $(arch) = "x86_64" ]; then
	Architecture=$ARCH_64
else
	Architecture=$ARCH_32
fi

# Start the setup program
LinuxSetupMenu

