#! /bin/sh

# This script is called by "cs101client" when is necessary to display a message

# Available parameters:
# $1 = "TITLE", title of the message
# $2 = "MESSAGE", text of the message
# $3 = "ICON", type of the message (info, warning, error, debug)
TITLE="$1"
MESSAGE="$2"
ICON="$3"

# enables/disables the console message (all users)
USE_WALL_MESSAGE=TRUE

# enables/disables the graphical popup message
USE_GUI_MESSAGE=TRUE


# product name, it is displayed before the TITLE
PRODUCT="CS101 Shutdown Client"

INSTALL_DIR=/usr/legrand/cs101/client

# graphical messagebox program
XMSGBOX=$INSTALL_DIR/xmsgbox

# display and xauthority settings
DISPLAY_SETTINGS=/var/tmp/.local-display-setup.sh


#
# Displays the message on the consoles of all users
#
ConsoleMessage()
{
	OLD="@"
	NEW=" "
	TEXT=`echo "$MESSAGE" | sed "s/$OLD/$NEW/g"`

	wall <<- EOF
		$PRODUCT : $TITLE
		$TEXT
	EOF
}

#
# Try to display the message on the X screen
#
GuiMessage()
{
	if [ -x "$XMSGBOX" ]; then
		# load display and xauthority settings
		if [ -e "$DISPLAY_SETTINGS" ]; then
			. $DISPLAY_SETTINGS
		fi
		$XMSGBOX "$TITLE" "$MESSAGE" "$ICON" >/dev/null 2>&1
	else
		return 1
	fi
	
	return 0
}



# --- START ---

# if enabled, print the message to all the console
if [ "$USE_WALL_MESSAGE" = "TRUE" ]; then
	ConsoleMessage
fi

# if enabled, try to display the popup message on the desktop
if [ "$USE_GUI_MESSAGE" = "TRUE" ]; then
	GuiMessage || ERROR=1 &
fi

exit ${ERROR:-0}
